/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';
import 'package:oktoast/oktoast.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/atoms/atoms.dart';

/// Custom class to show toast message
class ZwapToasts{

  static Widget toastWidget(String normalText, String emojiName, Color toastColor) => Center(
    child: ClipRRect(
      borderRadius: BorderRadius.circular(6),
      child: Container(
        decoration: BoxDecoration(
          boxShadow: [
            BoxShadow(
                color: Color.fromRGBO(199, 199, 199, 0.5),
                blurRadius: 30,
                spreadRadius: 4,
                offset: Offset(0, 15)
            )
          ]
        ),
        width: 40.0,
        height: 40.0,
        color: Colors.grey.withOpacity(0.3),
        child: Padding(
          padding: EdgeInsets.symmetric(vertical: 5, horizontal: 10),
          child: Row(
            children: [
              Flexible(
                flex: 0,
                fit: FlexFit.tight,
                child: Padding(
                  padding: EdgeInsets.only(right: 6),
                  child: ZwapText(
                    text: '\u{1F600}',
                    textColor: ZwapColors.neutral300,
                    zwapTextType: ZwapTextType.body1Regular,
                  ),
                ),
              ),
              Flexible(
                flex: 0,
                fit: FlexFit.tight,
                child: Padding(
                  padding: EdgeInsets.symmetric(horizontal: 6),
                  child: ZwapText(
                    zwapTextType: ZwapTextType.h3,
                    text: normalText,
                    textColor: ZwapColors.shades0,
                  ),
                ),
              ),
              Flexible(
                flex: 0,
                fit: FlexFit.tight,
                child: Padding(
                  padding: EdgeInsets.only(left: 6),
                  child: ZwapIcons.icons("close"),
                ),
              )
            ],
          ),
        ),
      ),
    ),
  );

  /// It shows the modal
  static void showMeetingConfirmed(String meetingConfirmedText, {Duration? duration}){
    showToastWidget(
      ZwapToasts.toastWidget(meetingConfirmedText, "Check Mark Button", ZwapColors.success700, ),
      duration: duration ?? const Duration(seconds: 1),
      position: ToastPosition.top,
    );
  }

  /// It shows an error toast message
  static void showErrorToast(String errorToastMessage, {Duration? duration}){
    showToastWidget(
      ZwapToasts.toastWidget(errorToastMessage, "Dizzy Face", ZwapColors.error400, ),
      duration: duration ?? const Duration(seconds:  1),
      position: ToastPosition.top,
    );
  }


}